spacepy.time.leapyear — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- previous |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »

# spacepy.time.leapyear

`spacepy.time.` `leapyear`(year, numdays=False)

  return an array of boolean leap year, a lot faster than the mod method that is normally seen

  Parameters: | year : array_like array of years numdays : boolean (optional) optionally return the number of days in the year
  Returns: | out : numpy array an array of boolean leap year, or array of number of days

  Examples

      >>> import numpy
      >>> import spacepy.time
      >>> spacepy.time.leapyear(numpy.arange(15)+1998)
      [False, False,  True, False, False, False,  True, False, False,
            False,  True, False, False, False,  True]

### Navigation

- index
- modules |
- modules |
- previous |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »